@@ -119,7 +119,7 @@ class ParallelTransformerBlock(nn.Module):
         dim_head = 64,
         causal = True,
         heads = 8,
-        qk_rmsnorm = True,
+        qk_rmsnorm = False,
         qk_scale = 8,
         ff_mult = 4,
         attn_dropout = 0.,
@@ -291,7 +291,7 @@ class PaLM(nn.Module):
         ff_mult = 4,
         attn_dropout = 0.,
         ff_dropout = 0.,
-        qk_rmsnorm = True,
+        qk_rmsnorm = False,
         lora_r = 8,
         rotary_xpos_scale_base = 512,
         finetune_scopes = tuple(),
